@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Process::Status;
 # ABSTRACT: a handle on process termination, like $?
-$Process::Status::VERSION = '0.006';
+$Process::Status::VERSION = '0.007';
 use Config ();
 
 #pod =head1 OVERVIEW
@@ -145,9 +145,31 @@ sub as_string {
   return $str;
 }
 
+#pod =method assert_ok
+#pod
+#pod   Process::Status->assert_ok($program_name);
+#pod
+#pod This method does nothing if C<$?> is 0.  Otherwise, it croaks with a message
+#pod like:
+#pod
+#pod   your-program-name exited 13, caught SIGNES
+#pod
+#pod If a program name is not provided, "program" is used.
+#pod
+#pod =cut
+
+sub assert_ok {
+  my $self = $_[0]->_self;
+  return if $$self == 0;
+  my $name = @_ > 1 ? $_[1] : "program";
+
+  require Carp;
+  Carp::croak("$name " . $self->as_string);
+}
+
 {
   package Process::Status::Negative;
-$Process::Status::Negative::VERSION = '0.006';
+$Process::Status::Negative::VERSION = '0.007';
 BEGIN { our @ISA = 'Process::Status' }
   sub status_code { $_[0][0] }
   sub pid_t       { $_[0][0] } # historical nonsense
@@ -183,7 +205,7 @@ Process::Status - a handle on process termination, like $?
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 OVERVIEW
 
@@ -248,6 +270,17 @@ Roughly, you might get things like this:
   exited 2, caught SIGDERP
   exited 2, caught SIGSEGV; dumped core
 
+=head2 assert_ok
+
+  Process::Status->assert_ok($program_name);
+
+This method does nothing if C<$?> is 0.  Otherwise, it croaks with a message
+like:
+
+  your-program-name exited 13, caught SIGNES
+
+If a program name is not provided, "program" is used.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
